"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = exports.LogType = void 0;
const tslib_1 = require("tslib");
const colors_1 = tslib_1.__importDefault(require("colors"));
/**
 * Represents the log type.
 */
var LogType;
(function (LogType) {
    LogType["Danger"] = "danger";
    LogType["Debug"] = "debug";
    LogType["Info"] = "info";
    LogType["Start"] = "start";
    LogType["Warn"] = "warn";
})(LogType || (exports.LogType = LogType = {}));
/**
 * Represents an easy-api.ts logger.
 */
class Logger {
    /**
     * Retrieves the date as locale string.
     * @returns {string}
     */
    static dateString = () => new Date().toLocaleString();
    /**
     * Logs a danger message.
     * @param message - Message to be logged.
     */
    static danger(message) {
        console.log(`${colors_1.default.green(Logger.dateString())} | ${colors_1.default.red(message)}`);
    }
    /**
     * Logs a message as information.
     * @param message - Message to be logged.
     */
    static info(message) {
        console.log(`${colors_1.default.green(Logger.dateString())} | ${colors_1.default.green(message)}`);
    }
    /**
     * Logs a warn message.
     * @param message - Message to be logged.
     */
    static warn(message) {
        console.log(`${colors_1.default.green(Logger.dateString())} | ${colors_1.default.yellow(message)}`);
    }
    /**
     * Logs a message in the console.
     * @param type - Log type.
     * @param message - Message to be logged.
     */
    static log(type, message) {
        this[type](message);
    }
    static start(version) {
        console.log(`${colors_1.default.green(Logger.dateString())} | ${colors_1.default.green("Running on")}: ${colors_1.default.bold("easy-api")}${colors_1.default.blue(".ts")} => ${colors_1.default.bold(version)}`);
    }
}
exports.Logger = Logger;
