"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReaderV2 = exports.ReaderV1 = exports.ReaderType = void 0;
/**
 * Check if the provided character is alphabetic.
 * @param char The character to check.
 * @returns {boolean}
 */
function isLetter(char) {
    return /[a-zA-Z]/.test(char);
}
/**
 * Check if the provided character is skippable.
 * @param char The chaacter to check.
 * @returns {boolean}
 */
function isSkippable(char) {
    return [" ", "\n"].includes(char);
}
/**
 * Check if the provided character is skippable.
 * @param char The chaacter to check.
 * @returns {boolean}
 */
function isEnd(char) {
    return ["]"].includes(char);
}
class ReaderType {
    static FunctionName = "FUNCTION_NAME";
    static FunctionParams = "FUNCTION_PARAMETERS";
    static Text = "TEXT";
}
exports.ReaderType = ReaderType;
class ReaderV1 {
    static read(c, trim = true) {
        let type = ReaderType.Text, depth = 0, inside = false, tokens = [], code = [...c.split("\n").map((line) => trim ? line.trim() : line).join("\n")];
        for (let i = 0; i < code.length; i++) {
            const char = code[i];
            if (char === "[")
                depth++;
            else if (char === "]")
                depth--;
            if (char === "$" &&
                type === ReaderType.Text &&
                code.at(i + 1) !== ":") {
                type = ReaderType.FunctionName;
            }
            else if (char !== "$" &&
                type === ReaderType.FunctionName &&
                !/[a-zA-Z]/.test(`${code.at(i)}`) &&
                char !== ":") {
                type = ReaderType.Text;
            }
            else if (char === ":" &&
                /[a-zA-Z]/.test(`${code.at(i + 1)}`) &&
                type === ReaderType.FunctionName) {
                type = ReaderType.Text;
            }
            else if (char === ":" &&
                !/[a-zA-Z]/.test(`${code.at(i + 1)}`) &&
                type === ReaderType.FunctionName &&
                inside === false) {
                inside = true;
                type = ReaderType.FunctionParams;
            }
            else if (char === "]" &&
                type === ReaderType.FunctionParams &&
                depth === 0) {
                tokens.push({ type, value: char });
                type = ReaderType.Text;
                inside = false;
                continue;
            }
            else if ((char === " " || char === "\n") &&
                /[a-zA-Z]/.test(`${code[i + 1]}`) &&
                depth === 0) {
                type = ReaderType.Text;
            }
            ;
            tokens.push({ type, value: char });
        }
        return tokens;
    }
}
exports.ReaderV1 = ReaderV1;
;
class ReaderV2 {
    static read(c, trim = true) {
        let type = ReaderType.Text, depth = 0;
        let tokens = [];
        if (trim) {
            c = c.split("\n").map(x => x.trim()).join("\n");
        }
        for (let i = 0; i < c.length; i++) {
            const char = c[i], next = c[i + 1];
            if (char === "[")
                depth++;
            else if (char === "]")
                depth--;
            if (type === ReaderType.Text) {
                if (char === "$" && isLetter(next)) {
                    type = ReaderType.FunctionName;
                    tokens.push({ type, value: char });
                }
                else
                    tokens.push({ type, value: char });
            }
            else if (type === ReaderType.FunctionName) {
                if (char === "[") {
                    type = ReaderType.FunctionParams;
                    tokens.push({ type, value: char });
                }
                else if (!isLetter(char)) {
                    type = ReaderType.Text;
                    tokens.push({ type, value: char });
                }
                else
                    tokens.push({ type, value: char });
            }
            else if (type === ReaderType.FunctionParams) {
                if (char === "]" && depth <= 0) {
                    tokens.push({ type, value: char });
                    type = ReaderType.Text;
                }
                else
                    tokens.push({ type, value: char });
            }
        }
        return tokens;
    }
}
exports.ReaderV2 = ReaderV2;
