"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class ArrayForEach extends APIFunction_1.APIFunction {
    name = "$arrayForEach";
    description = "Executes a code field for each array element.";
    parameters = [{
            name: "Name",
            description: "The name of the array.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Code",
            description: "Code to be executed.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$arrayForEach[name;code]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = false;
    async run(d, [name, code]) {
        name = await Util_1.Util.resolveCode(d, name);
        if (!d.internalVarExists(`NodeJS.Arrays:${name}`)) {
            throw new Error_1.EATS_Error(`Invalid array name in: ${d.function?.name}`);
        }
        const array = d.getInternalVar(`NodeJS.Arrays:${name}`);
        for (const element of array) {
            const replaced = code.replace(/\%element%/ig, element);
            const resolved = await Util_1.Util.resolveCode(d, replaced);
        }
    }
}
exports.default = ArrayForEach;
;
