"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class ArrayRemove extends APIFunction_1.APIFunction {
    name = "$arrayRemove";
    description = "Removes the provided array element by its index.";
    parameters = [{
            name: "Name",
            description: "The name of the array.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Index",
            description: "Element index to be removed.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$arrayRemove[name;index]";
    returns = APIFunction_1.ParamType.String;
    aliases = [];
    compile = true;
    async run(d, [name, index]) {
        if (!d.internalVarExists(`NodeJS.Arrays:${name}`)) {
            throw new Error_1.EATS_Error(`Invalid array name in: ${d.function?.name}`);
        }
        const array = d.getInternalVar(`NodeJS.Arrays:${name}`);
        if (!Util_1.Util.isNumber(index) || Number(index) < 1 || Number(index) > array?.length) {
            throw new Error_1.EATS_Error("Invalid index in: " + d.function?.name);
        }
        const removed = array.splice(Number(index) - 1, 1)[0];
        return removed;
    }
}
exports.default = ArrayRemove;
;
