"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
class ArrayUnshift extends APIFunction_1.APIFunction {
    name = "$arrayUnshift";
    description = "Adds elements to the beginning of the array";
    parameters = [{
            name: "Name",
            description: "The name of the array.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Elements",
            description: "Elements to be added to the array.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: true,
            defaultValue: null
        }];
    usage = "$arrayUnshift[name;...elements]";
    returns = APIFunction_1.ParamType.Number;
    aliases = [];
    compile = true;
    async run(d, [name, ...elements]) {
        if (!d.internalVarExists(`NodeJS.Arrays:${name}`)) {
            throw new Error_1.EATS_Error(`Invalid array name in: ${d.function?.name}`);
        }
        const array = d.getInternalVar(`NodeJS.Arrays:${name}`);
        const removed = array.unshift(...elements);
        d.setInternalVar(`NodeJS.Arrays:${name}`, array);
        return removed.toString();
    }
}
exports.default = ArrayUnshift;
;
