"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class BufferAlloc extends APIFunction_1.APIFunction {
    name = "$bufferAlloc";
    description = "Allocates a buffer.";
    parameters = [{
            name: "Name",
            description: "The name of the array.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Bytes",
            description: "Buffer byte length.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$bufferAlloc[name;bytes]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = true;
    async run(d, [name, bytes]) {
        if (!d.internalVarExists(`NodeJS.Buffers:${name}`)) {
            throw new Error_1.EATS_Error("Invalid buffer name in: " + d.function?.name);
        }
        else if (!Util_1.Util.isNumber(bytes)) {
            throw new Error_1.EATS_Error("Invalid bytes number in: " + d.function?.name);
        }
        d.setInternalVar(`NodeJS.Buffers:${name}`, Buffer.alloc(Number(bytes)));
    }
}
exports.default = BufferAlloc;
;
