"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const fs_1 = require("fs");
class BufferSave extends APIFunction_1.APIFunction {
    name = "$bufferSave";
    description = "Save the requested buffer into your file system.";
    parameters = [{
            name: "Name",
            description: "The name of the array.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Path",
            description: "Path to save the file to, must include extension.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$bufferSave[name;path (with file extension)]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = true;
    async run(d, [name, path]) {
        if (!d.internalVarExists(`NodeJS.Buffers:${name}`)) {
            throw new Error_1.EATS_Error("Invalid buffer name in: " + d.function?.name);
        }
        const buffer = d.getInternalVar(`NodeJS.Buffers:${name}`);
        try {
            (0, fs_1.writeFileSync)(path, buffer);
        }
        catch (e) {
            console.log("Cannot save the provided buffer.\n" + e);
        }
    }
}
exports.default = BufferSave;
;
