"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const canvas_1 = require("@napi-rs/canvas");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const Util_1 = require("../../classes/Util");
class AddEffect extends APIFunction_1.APIFunction {
    name = "$addEffect";
    description = "Adds an effect to the canvas.";
    parameters = [{
            name: "Effect",
            description: "The name of the effect.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null,
            enum: ['blur', 'brightness', 'contrast', 'grayscale', 'invert', 'saturate', 'sepia']
        }, {
            name: "Amount",
            description: "Filter amount to be applied.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$addEffect[name;amount]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = true;
    parent = new createCanvas_1.default;
    async run(d, [name, amount]) {
        if (!this.parameters[0].enum.includes(name.toLowerCase())) {
            throw new Error_1.EATS_Error(`Invalid effect name at: ${d.function?.name}`);
        }
        else if (!Util_1.Util.isNumber(amount)) {
            throw new Error_1.EATS_Error(`Invalid effect amount at: ${d.function?.name}, must be a valid number!`);
        }
        const canvas = d.parent.getInternalVar(`NodeJS.Canvas`);
        if (!(canvas instanceof canvas_1.Canvas)) {
            throw new Error_1.EATS_Error(`Environment#canvas is not a instance of Canvas: "${d.function?.name}"`);
        }
        const ctx = d.parent.getInternalVar("NodeJS.CanvasContext");
        ctx.filter = `${name}(${amount}${name === "blur" ? "px" : "%"})`;
        ctx.save();
    }
}
exports.default = AddEffect;
