"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const canvas_1 = require("@napi-rs/canvas");
const Util_1 = require("../../classes/Util");
class Color extends APIFunction_1.APIFunction {
    name = "$color";
    description = "Set the canvas color.";
    parameters = [{
            name: "Hexadecimal Code",
            description: "A valid hexadecimal code to put as color.",
            type: APIFunction_1.ParamType.Color,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$color[hexCode]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = true;
    parent = new createCanvas_1.default;
    async run(d, [color]) {
        if (!Util_1.Util.isValidHex(color)) {
            throw new Error_1.EATS_Error(`Invalid hexadecimal color at: "${d.function?.name}"`);
        }
        const canvas = d.parent.getInternalVar("NodeJS.Canvas");
        if (!(canvas instanceof canvas_1.Canvas)) {
            throw new Error_1.EATS_Error(`Environment#canvas is not a instance of Canvas: "${d.function?.name}"`);
        }
        const ctx = d.parent.getInternalVar("NodeJS.CanvasContext");
        ctx.fillStyle = "#".concat(color.replace("#", ""));
        ctx.save();
    }
}
exports.default = Color;
