"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const fs_1 = require("fs");
class DownloadImage extends APIFunction_1.APIFunction {
    name = "$downloadImage";
    description = "Downloads a cached image into your file system.";
    parameters = [{
            name: "Image ID",
            description: "Cached image ID to be downloaded.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Path",
            description: "File path to download the image to.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$downloadImage[id;path]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = true;
    parent = new createCanvas_1.default;
    async run(d, [id, path]) {
        const image = d.parent.getInternalVar(`NodeJS.Images:${id}`);
        if (!image) {
            throw new Error_1.EATS_Error(`Unable to find a valid image with ID: "${id}" at "${d.function?.name}"`);
        }
        else if (!Object.prototype.hasOwnProperty.call(image, "src")) {
            throw new Error_1.EATS_Error(`Unable to find a valid image with ID: "${id}" at "${d.function?.name}"`);
        }
        (0, fs_1.writeFileSync)(path, image.src);
    }
}
exports.default = DownloadImage;
