"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const canvas_1 = require("@napi-rs/canvas");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const Util_1 = require("../../classes/Util");
class DrawRect extends APIFunction_1.APIFunction {
    name = "$drawRect";
    description = "Draws a rectangle over the canvas.";
    parameters = [{
            name: "X",
            description: "X coordinate to place the rectangle to.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Y",
            description: "Y coordinate to place the rectangle to.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Width",
            description: "Rectangle width.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Height",
            description: "Rectangle height.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Radius",
            description: "Rectangle corner radius.",
            type: APIFunction_1.ParamType.Number,
            required: false,
            rest: false,
            defaultValue: "0"
        }];
    usage = "$drawRect[x;y;width;height;radius?]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = true;
    parent = new createCanvas_1.default;
    async run(d, [x, y, width, height, radius = "0"]) {
        if (d.function?.fields.slice(0, 5).some(x => !Util_1.Util.isNumber(x))) {
            throw new Error_1.EATS_Error(`Invalid numbers at: ${d.function?.name}, must be a valid number!`);
        }
        const canvas = d.parent.getInternalVar("NodeJS.Canvas");
        if (!(canvas instanceof canvas_1.Canvas)) {
            throw new Error_1.EATS_Error(`Unable to find a valid Canvas instance, you must start it using $setDimensions[...args]!`);
        }
        const ctx = d.parent.getInternalVar("NodeJS.CanvasContext");
        Util_1.Util.molde(ctx, Number(x), Number(y), Number(width), Number(height), parseInt(radius));
        ctx.clip();
        ctx.fillRect(Number(x), Number(y), Number(width), Number(height));
        ctx.restore();
        ctx.save();
    }
}
exports.default = DrawRect;
