"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const canvas_1 = require("@napi-rs/canvas");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const Util_1 = require("../../classes/Util");
const ALIGN_POSITIONS = ["left", "center", "right"];
const VERTICAL_ALIGN_POSITIONS = ["top", "middle", "bottom"];
class DrawText extends APIFunction_1.APIFunction {
    name = "$drawText";
    description = "Draws a text over the canvas.";
    parameters = [{
            name: "Text",
            description: "The text to be placed in the canvas.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "X",
            description: "X coordinate to place the text to.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Y",
            description: "Y coordinate to place the text to.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Width",
            description: "Textbox width.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Height",
            description: "Textbox height.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Align",
            description: "Text align.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: "left",
            enum: ["left", "right", "center"]
        }, {
            name: "Vertical Align",
            description: "Text vertical align.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: "top",
            enum: ["top", "middle", "bottom"]
        }];
    usage = "$drawText[text;x;y;width;height;align?;vAlign?]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = true;
    parent = new createCanvas_1.default;
    async run(d, [text, x, y, width, height, align = "left", vAlign = "top"]) {
        if (d.function?.fields.slice(1, 5).some(x => !Util_1.Util.isNumber(x))) {
            throw new Error_1.EATS_Error(`Invalid numbers at: ${d.function?.name}, must be a valid number!`);
        }
        else if (!ALIGN_POSITIONS.includes(align.toLowerCase())) {
            throw new Error_1.EATS_Error(`Invalid align position at: ${d.function?.name}`);
        }
        else if (!VERTICAL_ALIGN_POSITIONS.includes(vAlign.toLowerCase())) {
            throw new Error_1.EATS_Error(`Invalid vertical align position at: ${d.function?.name}`);
        }
        const canvas = d.parent.getInternalVar("NodeJS.Canvas");
        if (!(canvas instanceof canvas_1.Canvas)) {
            throw new Error_1.EATS_Error(`Unable to find a valid Canvas instance, you must start it using $setDimensions[...args]!`);
        }
        const ctx = d.parent.getInternalVar("NodeJS.CanvasContext");
        Util_1.Util.fillText(ctx, text, Number(x), Number(y), Number(width), Number(height), align, vAlign);
    }
}
exports.default = DrawText;
