"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const canvas_1 = require("@napi-rs/canvas");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const Util_1 = require("../../classes/Util");
class Font extends APIFunction_1.APIFunction {
    name = "$font";
    description = "Set the canvas font.";
    parameters = [{
            name: "Size",
            description: "Font size.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Family",
            description: "Font family.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: "Arial"
        }, {
            name: "Style",
            description: "Font style.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: "",
            enum: ["bold", "italic", "normal", "oblique"]
        }];
    usage = "$font[size;family?;style?]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = true;
    parent = new createCanvas_1.default;
    async run(d, [size, family = "Arial", style]) {
        if (!Util_1.Util.isNumber(size)) {
            throw new Error_1.EATS_Error(`Invalid font size at: ${d.function?.name}, must be a valid number!`);
        }
        const canvas = d.parent.getInternalVar("NodeJS.Canvas");
        if (!(canvas instanceof canvas_1.Canvas)) {
            throw new Error_1.EATS_Error(`Environment#canvas is not a instance of Canvas: "${d.function?.name}"`);
        }
        const ctx = d.parent.getInternalVar("NodeJS.CanvasContext");
        ctx.font = `${style ? style + " " : ""}${size}px ${family}`;
    }
}
exports.default = Font;
