"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const canvas_1 = require("@napi-rs/canvas");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const Util_1 = require("../../classes/Util");
class LoadImage extends APIFunction_1.APIFunction {
    name = "$loadImage";
    description = "Load a new image and save it using the given ID.";
    parameters = [{
            name: "Image ID",
            description: "Image identificator.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Type",
            description: "Source type.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null,
            enum: ["path", "url", "link"]
        }, {
            name: "Source",
            description: "Source to get the image from.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$loadImage[id;type;source]";
    returns = APIFunction_1.ParamType.Boolean;
    aliases = [];
    compile = true;
    parent = new createCanvas_1.default;
    async run(d, [id, type, source]) {
        const image = await (0, canvas_1.loadImage)(source);
        d.parent.setInternalVar(`NodeJS.Images:${id}`, image);
        return Util_1.Util.stringBool(image instanceof canvas_1.Image);
    }
}
exports.default = LoadImage;
