"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const canvas_1 = require("@napi-rs/canvas");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const Util_1 = require("../../classes/Util");
const MEASURING_TYPES = ["object", "width", "height"];
class MeasureText extends APIFunction_1.APIFunction {
    name = "$measureText";
    description = "Measure all dimensions of a text.";
    parameters = [{
            name: "Text",
            description: "The text to be placed in the canvas.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Type",
            description: "Return data style.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$measureText[text;type]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = true;
    parent = new createCanvas_1.default;
    async run(d, [text, type]) {
        if (!MEASURING_TYPES.includes(type.toLowerCase())) {
            throw new Error_1.EATS_Error(`Invalid measuring return type at: ${d.function?.name}`);
        }
        const canvas = d.parent.getInternalVar("NodeJS.Canvas");
        if (!(canvas instanceof canvas_1.Canvas)) {
            throw new Error_1.EATS_Error(`Unable to find a valid Canvas instance, you must start it using $setDimensions[...args]!`);
        }
        const ctx = d.parent.getInternalVar("NodeJS.CanvasContext");
        const data = {
            width: ctx.measureText(text).width,
            height: Util_1.Util.getTextHeight(ctx, text, ctx.font)
        };
        return type === "object" ? JSON.stringify(data) : type === "width" ? data.width.toString() : data.height.toString();
    }
}
exports.default = MeasureText;
