"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const canvas_1 = require("@napi-rs/canvas");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const Util_1 = require("../../classes/Util");
class Opacity extends APIFunction_1.APIFunction {
    name = "$opacity";
    description = "Set the canvas opacity.";
    parameters = [{
            name: "Amount",
            description: "Context amount to be applied.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$opacity[amount]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = true;
    parent = new createCanvas_1.default;
    async run(d, [amount]) {
        if (!Util_1.Util.isNumber(amount)) {
            throw new Error_1.EATS_Error(`Invalid context amount at: "${d.function?.name}", must be a valid number.`);
        }
        const canvas = d.parent.getInternalVar("NodeJS.Canvas");
        if (!(canvas instanceof canvas_1.Canvas)) {
            throw new Error_1.EATS_Error(`Environment#canvas is not a instance of Canvas: "${d.function?.name}"`);
        }
        const amt = parseInt(amount);
        const ctx = d.parent.getInternalVar("NodeJS.CanvasContext");
        if (amt < 0 || amt > 100) {
            throw new Error_1.EATS_Error(`Invalid context amount at: "${d.function?.name}", must be a valid number between 0 and 100.`);
        }
        ctx.globalAlpha = Util_1.Util.resolvePercent(Number(amount));
    }
}
exports.default = Opacity;
