"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const canvas_1 = require("@napi-rs/canvas");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const Util_1 = require("../../classes/Util");
class Rotate extends APIFunction_1.APIFunction {
    name = "$rotate";
    description = "Rotates a canvas.";
    parameters = [{
            name: "Angle",
            description: "Rotation angle.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$rotate[angle]";
    returns = APIFunction_1.ParamType.Unknown;
    compile = true;
    aliases = [];
    parent = new createCanvas_1.default;
    async run(d, [angle]) {
        if (!Util_1.Util.isNumber(angle)) {
            throw new Error_1.EATS_Error(`Invalid rotation angle at: ${d.function.name}`);
        }
        const parsedAngle = parseInt(angle);
        if (parsedAngle > 360 || parsedAngle < 0) {
            throw new Error_1.EATS_Error(`Invalid rotation angle at: ${d.function.name}`);
        }
        const canvas = d.parent.getInternalVar("NodeJS.Canvas");
        if (!(canvas instanceof canvas_1.Canvas)) {
            throw new Error_1.EATS_Error(`Unable to find a valid Canvas instance, you must start it using $setDimensions[...args]!`);
        }
        const ctx = d.parent.getInternalVar("NodeJS.CanvasContext");
        ctx.rotate(parsedAngle);
    }
}
exports.default = Rotate;
