"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const canvas_1 = require("@napi-rs/canvas");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const Util_1 = require("../../classes/Util");
class SetDimensions extends APIFunction_1.APIFunction {
    name = "$setDimensions";
    description = "Set the width and height of the canvas to be created.";
    parameters = [{
            name: "Width",
            description: "Canvas width.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Height",
            description: "Canvas height.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$setDimentions[width;height]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = ["$setDimentions"];
    compile = true;
    parent = new createCanvas_1.default;
    async run(d, [width, height]) {
        if (!Util_1.Util.isNumber(width)) {
            throw new Error_1.EATS_Error(`Invalid canvas width at: "${d.function?.name}", must be a valid number!`);
        }
        else if (!Util_1.Util.isNumber(height)) {
            throw new Error_1.EATS_Error(`Invalid canvas height at: "${d.function?.name}", must be a valid number!`);
        }
        const canvas = (0, canvas_1.createCanvas)(Number(width), Number(height));
        const context = canvas.getContext("2d");
        d.parent.setInternalVar('NodeJS.Canvas', canvas);
        d.parent.setInternalVar('NodeJS.CanvasContext', context);
    }
}
exports.default = SetDimensions;
