"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const canvas_1 = require("@napi-rs/canvas");
const Error_1 = require("../../structures/Error");
const createCanvas_1 = tslib_1.__importDefault(require("./createCanvas"));
const Util_1 = require("../../classes/Util");
class Translate extends APIFunction_1.APIFunction {
    name = "$translate";
    description = "Adds a translation transformation to the current matrix by moving the canvas and its origin \"X\" units horizontally and \"Y\" units vertically on the grid.";
    parameters = [{
            name: "X",
            description: "X coordinate to place the text to.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Y",
            description: "Y coordinate to place the text to.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$translate[x;y]";
    returns = APIFunction_1.ParamType.Unknown;
    compile = true;
    aliases = [];
    parent = new createCanvas_1.default;
    async run(d, [x, y]) {
        if (!Util_1.Util.isNumber(x)) {
            throw new Error_1.EATS_Error(`Invalid "X" coordinate at: ${d.function.name}`);
        }
        else if (!Util_1.Util.isNumber(y)) {
            throw new Error_1.EATS_Error(`Invalid "Y" coordinate at: ${d.function.name}`);
        }
        const [X, Y] = [parseInt(x), parseInt(y)];
        const canvas = d.parent.getInternalVar("NodeJS.Canvas");
        if (!(canvas instanceof canvas_1.Canvas)) {
            throw new Error_1.EATS_Error(`Unable to find a valid Canvas instance, you must start it using $setDimensions[...args]!`);
        }
        const ctx = d.parent.getInternalVar("NodeJS.CanvasContext");
        ctx.translate(X, Y);
    }
}
exports.default = Translate;
