"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Condition_1 = require("../../classes/Condition");
const Util_1 = require("../../classes/Util");
class OnlyIf extends APIFunction_1.APIFunction {
    name = "$onlyIf";
    description = "Executes a error code if the condition is not met.";
    parameters = [{
            name: "Expression",
            description: "The expression to be evaluated.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Error Code",
            description: "The code to be execute if the condition is not met.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$onlyIf[expression;errorCode]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = false;
    async run(d, [expression, then]) {
        expression = await Util_1.Util.resolveCode(d, expression);
        const conditionResult = new Condition_1.Condition().solve(expression);
        if (conditionResult === false) {
            await Util_1.Util.resolveCode(d, then);
            d.stopCode();
        }
    }
}
exports.default = OnlyIf;
