"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Condition_1 = require("../../classes/Condition");
const Util_1 = require("../../classes/Util");
class OR extends APIFunction_1.APIFunction {
    name = "$or";
    description = "Check wether at least one condition is met.";
    parameters = [{
            name: "Expression",
            description: "The expression to be evaluated.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: true,
            defaultValue: null
        }];
    usage = "$or[...expressions]";
    returns = APIFunction_1.ParamType.Boolean;
    aliases = [];
    compile = true;
    async run(d, [...expressions]) {
        const includesComp = expressions.some((txt) => txt.match(new RegExp(`(${new Condition_1.Condition().fullSymbols.join("|")})`, "g")));
        if (includesComp) {
            const results = [];
            expressions.forEach((expression) => {
                const evaluation = new Condition_1.Condition().solve(expression);
                results.push(evaluation);
            });
            return Util_1.Util.stringBool(results.some((res) => res === true));
        }
        else {
            for (const expression of expressions) {
                const result = new Condition_1.Condition().solve(expression);
                if (result) {
                    return expression;
                }
            }
            return Util_1.Util.stringBool(false);
        }
    }
}
exports.default = OR;
