"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class Switch extends APIFunction_1.APIFunction {
    name = "$switch";
    description = "Executes a switch statement.";
    parameters = [{
            name: "Value",
            description: "Value to be evaluated.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Cases",
            description: "Cases to be executed.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$switch[value;cases]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = false;
    async run(d, [value, cases]) {
        value = await Util_1.Util.resolveCode(d, value);
        const groups = new Map();
        const data = d.extend(d._, d.__);
        data.setInternalVar("NodeJS.SwitchCases", groups);
        data.functions.load(__dirname, (fn) => typeof fn.parent !== "undefined" && fn.parent.name === this.name);
        await Util_1.Util.resolveCode(data, cases);
        if (!groups.has("default")) {
            throw new Error_1.EATS_Error(`Missing default case in: ${d.function?.name}`);
        }
        let result = "";
        if (groups.has(value)) {
            const caseCode = groups.get(value);
            result = await Util_1.Util.resolveCode(data, caseCode);
        }
        else {
            const caseCode = groups.get("default");
            result = await Util_1.Util.resolveCode(data, caseCode);
        }
        return result;
    }
}
exports.default = Switch;
