"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Condition_1 = require("../../classes/Condition");
const Util_1 = require("../../classes/Util");
class Ternary extends APIFunction_1.APIFunction {
    name = "$ternary";
    description = "Executes a ternary statement.";
    parameters = [{
            name: "Expression",
            description: "The expression to be evaluated.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Then",
            description: "The code to be execute if the condition is met.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Else",
            description: "The code to be execute if the condition is not met.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: null
        }];
    usage = "$ternary[expression;then;else?]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = ["$if"];
    compile = false;
    async run(d, [expression, then, otherwise]) {
        expression = await Util_1.Util.resolveCode(d, expression);
        let result = "";
        const conditionResult = new Condition_1.Condition().solve(expression);
        if (conditionResult) {
            result = await Util_1.Util.resolveCode(d, then);
        }
        else if (typeof (otherwise) === "string") {
            result = await Util_1.Util.resolveCode(d, otherwise);
        }
        return result;
    }
}
exports.default = Ternary;
