"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Condition_1 = require("../../classes/Condition");
const Util_1 = require("../../classes/Util");
class While extends APIFunction_1.APIFunction {
    name = "$while";
    description = "While statement.";
    parameters = [{
            name: "Expression",
            description: "Expression to be evaluated.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Code",
            description: "Code to be executed.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Separator",
            description: "Text result separator to join the results.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: ","
        }];
    usage = "$while[condition;code;separator?]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = false;
    async run(d, [expression, code, separator = ","]) {
        let rawExpression = await Util_1.Util.resolveCode(d, expression);
        let conditionResult = new Condition_1.Condition().solve(rawExpression);
        let results = [];
        for (;;) {
            if (conditionResult === false)
                break;
            const resultCode = await Util_1.Util.resolveCode(d, code);
            results.push(resultCode);
            rawExpression = await Util_1.Util.resolveCode(d, expression);
            conditionResult = new Condition_1.Condition().solve(rawExpression);
        }
        results = results.filter((text) => text !== "");
        return results.join(separator);
    }
}
exports.default = While;
