"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
class AddPackage extends APIFunction_1.APIFunction {
    name = "$addPackage";
    description = "Adds a require package to the $jsEval code.";
    parameters = [{
            name: "Require Name",
            description: "How must this package be required.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Property",
            description: "Property to be required from the package. Use %default% to use the default CJS import: const package = require(\"package\")",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: "%DEFAULT%"
        }];
    usage = "$addPackage[requireName;property]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = ["$define"];
    compile = true;
    example = `
        $addPackage[mathjs;evaluate]
        $jsEval[false;console.log(evaluate("12 + 1"))]
    `;
    async run(d, [name, property = "%DEFAULT%"]) {
        if (!d.internalVarExists("ADD_PKGS"))
            d.setInternalVar("ADD_PKGS", []);
        const packages = d.getInternalVar("ADD_PKGS");
        packages.push({
            name,
            property: property.toLowerCase() === "%default%" ? null : property
        });
        d.setInternalVar("ADD_PKGS", packages);
    }
}
exports.default = AddPackage;
