"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class CallFunction extends APIFunction_1.APIFunction {
    name = "$call";
    description = "Calls a custom function.";
    parameters = [{
            name: "Name",
            description: "The name of the function to be called.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Parameters",
            description: "The parameter required for the custom function.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: true,
            defaultValue: null
        }];
    usage = "$call[name;...params]";
    returns = APIFunction_1.ParamType.String;
    aliases = ["$callback", "$callFunction"];
    compile = false;
    async run(d, [name, ...params]) {
        if (!d.internalVarExists(`NodeJS.Callbacks:${name}`))
            throw new Error_1.EATS_Error("Invalid function name in: " + d.function?.name);
        name = await Util_1.Util.resolveCode(d, name);
        let fnCode = d.getInternalVar(`NodeJS.Callbacks:${name}`);
        if (params[0] !== undefined) {
            for (let i = 0; i < params.length; i++) {
                const param = params[i];
                fnCode = fnCode.replace(new RegExp(`%PARAM_${i}%`, "ig"), param);
            }
        }
        const result = await Util_1.Util.resolveCode(d, fnCode);
        return result;
    }
}
exports.default = CallFunction;
