"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
const ms_1 = tslib_1.__importDefault(require("ms"));
class SetTimeout extends APIFunction_1.APIFunction {
    name = "$setTimeout";
    description = "Set a NodeJS timeout.";
    parameters = [{
            name: "Name",
            description: "The name for this timeout.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Time",
            description: "Time to execute the code.",
            type: APIFunction_1.ParamType.Time,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Code",
            description: "Code to be executed when the time ends.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$setTimeout[name;time;code]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = [];
    compile = false;
    async run(d, [name, time, code]) {
        if (d.internalVarExists(`NodeJS.Timeout:${name}`)) {
            throw new Error_1.EATS_Error(`There is already a timeout with that name at: ${d.function.name}`);
        }
        name = await Util_1.Util.resolveCode(d, name);
        time = await Util_1.Util.resolveCode(d, time);
        const parsedTime = (0, ms_1.default)(time);
        if (isNaN(parsedTime)) {
            throw new Error_1.EATS_Error(`Invalid time provided at: ${d.function.name}`);
        }
        const timeout = setTimeout(async () => {
            await Util_1.Util.resolveCode(d, code);
        }, parsedTime);
        d.setInternalVar(`NodeJS.Timeout:${name}`, timeout);
    }
}
exports.default = SetTimeout;
;
