"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Util_1 = require("../../classes/Util");
const colors_1 = tslib_1.__importDefault(require("colors"));
class Test extends APIFunction_1.APIFunction {
    name = "$test";
    description = "Test a code.";
    parameters = [{
            name: "Test Title",
            description: "Test title.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Expected",
            description: "Expected value of the test result.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Code",
            description: "Code to be tested.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$test[name;expect;code]";
    returns = APIFunction_1.ParamType.Unknown;
    compile = false;
    aliases = [];
    async run(d, [name, expect, code]) {
        // Resolving parameters.
        name = await Util_1.Util.resolveCode(d, name.replace(/"/g, "'"));
        expect = await Util_1.Util.resolveCode(d, expect);
        code = await Util_1.Util.resolveCode(d, code);
        if (code === expect) {
            console.log(`[${colors_1.default.bold("easy-api")}${colors_1.default.blue(".ts")} ${colors_1.default.yellow("TEST")}] "${colors_1.default.bold(name)}" => ${colors_1.default.green("PASSED")}`);
        }
        else {
            console.log(`[${colors_1.default.bold("easy-api")}${colors_1.default.blue(".ts")} ${colors_1.default.yellow("TEST")}] "${colors_1.default.bold(name)}" => ${colors_1.default.red("NOT PASSED")}`);
        }
    }
}
exports.default = Test;
