"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Util_1 = require("../../classes/Util");
class Try extends APIFunction_1.APIFunction {
    name = "$try";
    description = "Try to execute the given code, if something goes wrong, catch code is executed.";
    parameters = [{
            name: "Code",
            description: "Code to be executed.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Catch Code",
            description: "Code to be executed in case some error ocurrs.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Finally Code",
            description: "Code to be executed finally.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: null
        }];
    usage = "$try[code;catch;finally?]";
    returns = APIFunction_1.ParamType.Unknown;
    compile = false;
    aliases = [];
    async run(d, [code, catchCode, finallyCode]) {
        let resolved;
        try {
            resolved = await Util_1.Util.resolveCode(d, code);
        }
        catch (e) {
            catchCode = catchCode.replace(/%ERROR%/ig, e.message);
            resolved = await Util_1.Util.resolveCode(d, catchCode);
        }
        finally {
            if (finallyCode !== undefined) {
                resolved = await Util_1.Util.resolveCode(d, finallyCode);
            }
        }
        return resolved;
    }
}
exports.default = Try;
