"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const fs_1 = tslib_1.__importDefault(require("fs"));
class DeleteFile extends APIFunction_1.APIFunction {
    name = "$deleteFile";
    description = "Unlinks a path/file from the file system.";
    parameters = [{
            name: "Path",
            description: "The path of the file to be deleted.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$deleteFile[path]";
    returns = APIFunction_1.ParamType.Unknown;
    compile = true;
    aliases = ["$unlinkFile"];
    async run(d, [path]) {
        try {
            fs_1.default.unlinkSync(path);
        }
        catch (e) {
            throw new Error_1.EATS_Error([
                "Unable to unlink the path: " + d.function?.name,
                "with reason: " + e
            ].join("\n"));
        }
    }
}
exports.default = DeleteFile;
