"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
const fs_1 = tslib_1.__importDefault(require("fs"));
class FileSize extends APIFunction_1.APIFunction {
    name = "$fileSize";
    description = "Returns the file size.";
    parameters = [{
            name: "Path",
            description: "The path of the file to be checked.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Decimals",
            description: "How many decimals for the file size number.",
            type: APIFunction_1.ParamType.Number,
            required: false,
            rest: false,
            defaultValue: "2"
        }];
    usage = "$fileSize[path;decimals?]";
    returns = APIFunction_1.ParamType.Number;
    compile = true;
    aliases = [];
    async run(d, [path, decimals = "2"]) {
        if (!Util_1.Util.isNumber(decimals)) {
            throw new Error_1.EATS_Error("Invalid number in: " + d.function?.name);
        }
        try {
            const file = fs_1.default.statSync(path);
            return (file.size / 1024).toFixed(Number(decimals)).toString();
        }
        catch (e) {
            throw new Error_1.EATS_Error([
                "Unable to check the file path: " + d.function?.name,
                "with reason: " + e
            ].join("\n"));
        }
    }
}
exports.default = FileSize;
