"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const axios_1 = tslib_1.__importDefault(require("axios"));
const Error_1 = require("../../structures/Error");
class HTTPRequest extends APIFunction_1.APIFunction {
    name = "$httpRequest";
    description = "Makes an HTTP request.";
    parameters = [{
            name: "URL",
            description: "Target URL to make the request to.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Configuration",
            description: "Request typedConfig body.",
            type: APIFunction_1.ParamType.JSON,
            required: false,
            rest: false,
            defaultValue: JSON.stringify({})
        }];
    usage = "$httpRequest[URL;config?]";
    returns = APIFunction_1.ParamType.Unknown;
    compile = true;
    aliases = [];
    async run(d, [url, stringConfig = "{}"]) {
        if (!stringConfig.startsWith("{") && !stringConfig.endsWith("}")) {
            throw new Error_1.EATS_Error("Invalid request typedConfig object in: " + d.function?.name);
        }
        const requestConfig = JSON.parse(stringConfig);
        const typedConfig = {};
        typedConfig.url = url;
        typedConfig.method = requestConfig.method ?? "get";
        if (requestConfig.headers)
            typedConfig.headers = requestConfig.headers;
        if (requestConfig.data)
            typedConfig.data = requestConfig.data;
        if (requestConfig.params)
            typedConfig.params = requestConfig.params;
        if (requestConfig.timeout)
            typedConfig.timeout = requestConfig.timeout;
        if (requestConfig.withCredentials)
            typedConfig.withCredentials = requestConfig.withCredentials;
        if (requestConfig.auth)
            typedConfig.auth = requestConfig.auth;
        if (requestConfig.responseType)
            typedConfig.responseType = requestConfig.responseType;
        if (requestConfig.responseEncoding)
            typedConfig.responseEncoding = requestConfig.responseEncoding;
        if (requestConfig.xsrfCookieName)
            typedConfig.xsrfCookieName = requestConfig.xsrfCookieName;
        if (requestConfig.xsrfHeaderName)
            typedConfig.xsrfHeaderName = requestConfig.xsrfHeaderName;
        if (requestConfig.maxContentLength)
            typedConfig.maxContentLength = requestConfig.maxContentLength;
        if (requestConfig.maxBodyLength)
            typedConfig.maxBodyLength = requestConfig.maxBodyLength;
        if (requestConfig.maxRedirects)
            typedConfig.maxRedirects = requestConfig.maxRedirects;
        if (requestConfig.proxy)
            typedConfig.proxy = requestConfig.proxy;
        if (requestConfig.decompress)
            typedConfig.decompress = requestConfig.decompress;
        const requestResult = await (0, axios_1.default)(typedConfig).catch((e) => {
            if (requestConfig.logError)
                console.log(e);
            else
                return null;
        });
        if (requestResult === null || requestResult === undefined)
            return;
        if (!d.internalVarExists("EATS_REQUEST")) {
            d.setInternalVar("EATS_REQUEST", {
                status: null,
                body: null
            });
        }
        const structure = d.getInternalVar("EATS_REQUEST");
        Object.assign(structure, { status: requestResult.status });
        Object.assign(structure, { body: requestResult.data });
        d.setInternalVar("EATS_REQUEST", structure);
    }
}
exports.default = HTTPRequest;
