"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const _ = tslib_1.__importStar(require("lodash"));
class HTTPResult extends APIFunction_1.APIFunction {
    name = "$httpResult";
    description = "Retrieves a property from the HTTP request response.";
    parameters = [{
            name: "Path",
            description: "Property key path to be retrieved.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$httpResult[path]";
    returns = APIFunction_1.ParamType.Unknown;
    compile = true;
    aliases = [];
    async run(d, [path]) {
        if (!d.internalVarExists("EATS_REQUEST")) {
            throw new Error_1.EATS_Error("Missing request data in: " + d.function?.name);
        }
        const structure = d.getInternalVar("EATS_REQUEST");
        const result = path.toLowerCase() === "%default%"
            ? JSON.stringify(structure.body)
            : _.get(structure.body, path);
        return result === undefined
            ? "null" : typeof result === "object"
            ? JSON.stringify(result) : typeof result !== "string"
            ? result.toString() : result;
    }
}
exports.default = HTTPResult;
