"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
const os_1 = require("os");
function getCPU(d) {
    let avgs = (0, os_1.cpus)().map((cpu) => {
        const total = Object.values(cpu.times).reduce((a, b) => a + b), nonIdle = total - cpu.times.idle;
        return nonIdle / total;
    });
    return (avgs.reduce((a, b) => a + b) / (0, os_1.cpus)().length)
        .toFixed(d)
        .toString();
}
class GetCPU extends APIFunction_1.APIFunction {
    name = "$cpu";
    description = "Returns how many CPU is being used by the process.";
    parameters = [{
            name: "Decimals",
            description: "How many decimals to be attached to the return number.",
            type: APIFunction_1.ParamType.Number,
            required: false,
            rest: false,
            defaultValue: "2"
        }];
    usage = "$cpu[decimals?]";
    returns = APIFunction_1.ParamType.Number;
    compile = true;
    aliases = [];
    async run(d, [decimals = "2"]) {
        if (!Util_1.Util.isNumber(decimals))
            throw new Error_1.EATS_Error("Invalid number in: " + d.function?.name);
        return getCPU(Number(decimals));
    }
}
exports.default = GetCPU;
