"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class RAM extends APIFunction_1.APIFunction {
    name = "$ram";
    description = "Returns how many RAM is being used by the process.";
    parameters = [{
            name: "Type",
            description: "RAM type to be selected.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: "MB",
            enum: ["GB", "MB", "KB"]
        }, {
            name: "Decimals",
            description: "How many decimals to round the ram usage.",
            type: APIFunction_1.ParamType.Number,
            required: false,
            rest: false,
            defaultValue: "2"
        }];
    usage = "$ram[type?;decimals?]";
    returns = APIFunction_1.ParamType.Number;
    compile = true;
    aliases = [];
    async run(d, [type = "MB", decimals = "2"]) {
        if (!this.parameters[0].enum.includes(type.toUpperCase())) {
            throw new Error_1.EATS_Error("Invalid type in: " + d.function?.name);
        }
        else if (!Util_1.Util.isNumber(decimals)) {
            throw new Error_1.EATS_Error("Invalid number in: " + d.function?.name);
        }
        return ram(Number(decimals), type.toUpperCase());
    }
}
exports.default = RAM;
function ram(decimals, type) {
    let result = process.memoryUsage().rss / 1024;
    if (type === "MB")
        result = result / 1024;
    else if (type === "GB")
        result = result / 1024 / 1024;
    return result.toFixed(decimals).toString();
}
