"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class Divide extends APIFunction_1.APIFunction {
    name = "$varDivide";
    description = "Shorthand for $var[...;$calculate[$get[...] / $get[...]]].";
    parameters = [{
            name: "Name",
            description: "Variable name.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Amount",
            description: "Amount to divide the variable with.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$varDivide[varName;amount?]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = ["$varDiv", "$letDiv", "$setDiv"];
    compile = true;
    async run(d, [name, amount]) {
        if (!Util_1.Util.isNumber(amount)) {
            throw new Error_1.EATS_Error("Invalid number in: " + d.function?.name);
        }
        const variable = d.getVar(name);
        if (!Util_1.Util.isNumber(variable)) {
            throw new Error_1.EATS_Error(`Variable "${name}" is not a valid number at: ${d.function.name}`);
        }
        d.setVar(name, (Number(variable) / Number(amount)).toString());
    }
}
exports.default = Divide;
;
