"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class Reply extends APIFunction_1.APIFunction {
    name = "$reply";
    description = "Replies the HTTP request.";
    parameters = [{
            name: "Content",
            description: "Content to reply the request with.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$reply[content]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = ["$send", "$response"];
    compile = false;
    async run(d, [content]) {
        const data = d.extend(d._, d.__);
        data.functions.load(__dirname, (fn) => typeof fn.parent !== "undefined" && fn.parent.name === this.name);
        await Util_1.Util.resolveCode(data, content);
        const type = d.getInternalVar("NodeJS.ReplyType");
        const code = d.getInternalVar("NodeJS.ReplyCode");
        if (type === "json") {
            const structure = d.getInternalVar("NodeJS.ReplyData");
            d.res.code(code).type("application/json").send(structure);
        }
        else if (type === "file") {
            const mimeType = d.getInternalVar("NodeJS.MIMEType");
            const fileStream = d.getInternalVar("NodeJS.ReplyData");
            d.res.code(code).type(mimeType).send(fileStream);
        }
        else if (type === "redirect") {
            const path = d.getInternalVar("NodeJS.ReplyData");
            d.res.code(code).redirect(path);
        }
        else if (type === "other") {
            const text = d.getInternalVar("NodeJS.ReplyData");
            d.res.code(code).type("text/plain").send(text);
        }
        else if (type === "canvas") {
            const canvas = d.getInternalVar("NodeJS.ReplyData");
            if (!(canvas instanceof Buffer)) {
                throw new Error_1.EATS_Error(`Unable to find a valid canvas buffer instance, you must start a canvas using $setDimensions[...args]!`);
            }
            d.res.code(code).type("image/png").send(canvas);
        }
    }
}
exports.default = Reply;
