"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const reply_1 = tslib_1.__importDefault(require("./reply"));
const mime_types_1 = require("mime-types");
const path_1 = require("path");
const fs_1 = require("fs");
const canvas_1 = require("@napi-rs/canvas");
class SetBody extends APIFunction_1.APIFunction {
    name = "$setBody";
    description = "Set the response body.";
    parameters = [{
            name: "Body",
            description: "Body for the response to be set.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$setBody[body]";
    returns = APIFunction_1.ParamType.Unknown;
    compile = true;
    aliases = [];
    parent = new reply_1.default;
    async run(d, [body]) {
        const type = d.parent.getInternalVar("NodeJS.ReplyType");
        if (!type)
            throw new Error_1.EATS_Error(`Invalid reply type at: ${d.function.name}`);
        if (type === "json") {
            const structure = JSON.parse(body);
            d.parent.setInternalVar("NodeJS.ReplyData", structure);
        }
        else if (type === "file") {
            const mimeType = (0, mime_types_1.contentType)((0, path_1.extname)(body));
            const file = (0, fs_1.createReadStream)(body);
            d.parent.setInternalVar("NodeJS.MIMEType", mimeType);
            d.parent.setInternalVar("NodeJS.ReplyData", file);
        }
        else if (type === "redirect") {
            d.parent.setInternalVar("NodeJS.ReplyData", body);
        }
        else if (type === "other") {
            d.parent.setInternalVar("NodeJS.ReplyData", body);
        }
        else if (type === "canvas") {
            const canvas = d.parent.getInternalVar("NodeJS.Canvas");
            if (!(canvas instanceof canvas_1.Canvas)) {
                throw new Error_1.EATS_Error(`Unable to find a valid Canvas instance, you must start it using $setDimensions[...args]!`);
            }
            d.parent.setInternalVar("NodeJS.ReplyData", canvas.toBuffer("image/png"));
        }
    }
}
exports.default = SetBody;
