"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const reply_1 = tslib_1.__importDefault(require("./reply"));
/**
 * Represents all valid request reply types.
 */
const SEND_TYPES = ["canvas", "json", "file", "other", "redirect"];
class SetType extends APIFunction_1.APIFunction {
    name = "$setType";
    description = "Set the response type.";
    parameters = [{
            name: "Type",
            description: "Type for the response to be set.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null,
            enum: SEND_TYPES
        }];
    usage = "$setType[type]";
    returns = APIFunction_1.ParamType.Unknown;
    compile = true;
    aliases = [];
    parent = new reply_1.default;
    async run(d, [type]) {
        if (!SEND_TYPES.includes(type.toLowerCase())) {
            throw new Error_1.EATS_Error(`Invalid response type in: ${d.function?.name}`);
        }
        d.parent.setInternalVar('NodeJS.ReplyType', type.toLowerCase());
    }
}
exports.default = SetType;
