"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class ObjectAssign extends APIFunction_1.APIFunction {
    name = "$objectAssign";
    description = "Assign objects to a base object.";
    parameters = [{
            name: "Name",
            description: "The name of the object to assign structs to.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Objects",
            description: "Objects to be assigned.",
            type: APIFunction_1.ParamType.JSON,
            required: true,
            rest: true,
            defaultValue: null
        }];
    usage = "$objectAssign[name;...objects]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = ["$objectMix", "$jsonAssign"];
    compile = true;
    async run(d, [name, ...structures]) {
        if (!d.internalVarExists(`EATS_OBJ_${name}`)) {
            throw new Error_1.EATS_Error("Invalid object name in: " + d.function?.name);
        }
        for (const structure of structures) {
            if (!structure.startsWith("{") && !structure.endsWith("}")) {
                throw new Error_1.EATS_Error("Invalid object structure in: " + d.function?.name);
            }
            try {
                const parsed = Util_1.Util.parse(structure);
                if (typeof (parsed) !== "object") {
                    throw new Error_1.EATS_Error("Invalid object structure in: " + d.function?.name);
                }
                const base = d.getInternalVar(`EATS_OBJ_${name}`);
                Object.assign(base, parsed);
                d.setInternalVar(`EATS_OBJ_${name}`, base);
            }
            catch (error) {
                throw new Error_1.EATS_Error([
                    "Invalid object structure in: " + d.function?.name,
                    "with reason: " + error
                ].join("\n"));
            }
        }
    }
}
exports.default = ObjectAssign;
