"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
class ObjectCreate extends APIFunction_1.APIFunction {
    name = "$objectCreate";
    description = "Creates a new object.";
    parameters = [{
            name: "Name",
            description: "The name for the new object.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Structure",
            description: "A key-value pair object interface.",
            type: APIFunction_1.ParamType.JSON,
            required: false,
            rest: false,
            defaultValue: JSON.stringify({})
        }];
    usage = "$objectCreate[name;structure]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = ["$createObject", "$newObject"];
    compile = true;
    async run(d, [name, structure = "{}"]) {
        if (!structure.startsWith("{") && !structure.endsWith("}")) {
            throw new Error_1.EATS_Error("Invalid object structure in: " + d.function?.name);
        }
        try {
            const parsedStructure = JSON.parse(structure);
            d.setInternalVar(`EATS_OBJ_${name}`, parsedStructure);
        }
        catch (error) {
            throw new Error_1.EATS_Error([
                "Unable to parse the structure in: " + d.function?.name,
                "with reason: " + error
            ].join("\n"));
        }
    }
}
exports.default = ObjectCreate;
