"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class ObjectEntries extends APIFunction_1.APIFunction {
    name = "$objectEntries";
    description = "Returns a text from object entries.";
    parameters = [{
            name: "Name",
            description: "The name for the new object.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Text",
            description: "Text to be resolved.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Separator",
            description: "Text separator to join the results.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: ","
        }];
    usage = "$objectEntries[name;text;separator?]";
    returns = APIFunction_1.ParamType.String;
    aliases = [];
    compile = false;
    async run(d, [name, text, separator = ","]) {
        if (!d.internalVarExists(`EATS_OBJ_${name}`)) {
            throw new Error_1.EATS_Error("Invalid object name in: " + d.function?.name);
        }
        name = await Util_1.Util.resolveCode(d, name);
        text = await Util_1.Util.resolveCode(d, text);
        separator = await Util_1.Util.resolveCode(d, separator);
        const structure = d.getInternalVar(`EATS_OBJ_${name}`);
        let results = [];
        for (const [key, value] of Object.entries(structure)) {
            const replacedText = text.replace(/%KEY%/ig, key).replace(/%VALUE%/ig, value);
            const resolved = await Util_1.Util.resolveCode(d, replacedText);
            results.push(resolved);
        }
        results = results.filter(value => value !== "");
        return results.join(separator);
    }
}
exports.default = ObjectEntries;
