"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
const _ = tslib_1.__importStar(require("lodash"));
class ObjectHas extends APIFunction_1.APIFunction {
    name = "$objectIn";
    description = "Check if an object exists in the environment data.";
    parameters = [{
            name: "Name",
            description: "The name of the object.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Path",
            description: "Property path to be checked.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$objectIn[name;path]";
    returns = APIFunction_1.ParamType.Boolean;
    aliases = ["$objectHas"];
    compile = true;
    async run(d, [name, path]) {
        if (!d.internalVarExists(`EATS_OBJ_${name}`)) {
            throw new Error_1.EATS_Error("Invalid object name in: " + d.function?.name);
        }
        return Util_1.Util.stringBool(_.has(d.getInternalVar(`EATS_OBJ_${name}`), path));
    }
}
exports.default = ObjectHas;
