"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
class ObjectKeys extends APIFunction_1.APIFunction {
    name = "$objectKeys";
    description = "Joins the keys of an object.";
    parameters = [{
            name: "Name",
            description: "The name of the object.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Separator",
            description: "Text separator to join the object keys.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: ","
        }];
    usage = "$objectKeys[name;separator?]";
    returns = APIFunction_1.ParamType.String;
    aliases = [];
    compile = true;
    async run(d, [name, separator = ","]) {
        if (!d.internalVarExists(`EATS_OBJ_${name}`)) {
            throw new Error_1.EATS_Error("Invalid object name in: " + d.function?.name);
        }
        const structure = d.getInternalVar(`EATS_OBJ_${name}`);
        return Object.keys(structure).join(separator);
    }
}
exports.default = ObjectKeys;
