"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const _ = tslib_1.__importStar(require("lodash"));
class ObjectProperty extends APIFunction_1.APIFunction {
    name = "$objectProperty";
    description = "Returns a property from an object.";
    parameters = [{
            name: "Name",
            description: "The name of the object.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Path",
            description: "Object property path.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: null
        }];
    usage = "$objectProperty[name;path]";
    returns = APIFunction_1.ParamType.String;
    aliases = [];
    compile = true;
    async run(d, [name, path]) {
        if (!d.internalVarExists(`EATS_OBJ_${name}`)) {
            throw new Error_1.EATS_Error("Invalid object name in: " + d.function?.name);
        }
        const structure = d.getInternalVar(`EATS_OBJ_${name}`);
        const foundProperty = _.get(structure, path);
        return typeof (foundProperty) === "string" ? foundProperty
            : typeof (foundProperty) === "object" ? JSON.stringify(foundProperty)
                : typeof (foundProperty) === "number" ? foundProperty.toString()
                    : foundProperty;
    }
}
exports.default = ObjectProperty;
