"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const _ = tslib_1.__importStar(require("lodash"));
class ObjectSet extends APIFunction_1.APIFunction {
    name = "$objectSet";
    description = "Set a property in an object.";
    parameters = [{
            name: "Name",
            description: "The name of the object.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Path",
            description: "Object property path to be setted.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Value",
            description: "The value for the object property.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$objectSet[name;path;value]";
    returns = APIFunction_1.ParamType.Unknown;
    aliases = ["$setObjectKey", "$setObjectProperty"];
    compile = true;
    async run(d, [name, path, value]) {
        if (!d.internalVarExists(`EATS_OBJ_${name}`)) {
            throw new Error_1.EATS_Error("Invalid object name in: " + d.function?.name);
        }
        const structure = d.getInternalVar(`EATS_OBJ_${name}`);
        _.set(structure, path, value);
        d.setInternalVar(`EATS_OBJ_${name}`, structure);
    }
}
exports.default = ObjectSet;
