"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class EncodeURI extends APIFunction_1.APIFunction {
    name = "$execRegex";
    description = "Executes a regex in a string.";
    parameters = [{
            name: "Regex",
            description: "The regular expression to be executed.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Flags",
            description: "Regular expression flags.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: "g"
        }, {
            name: "Text",
            description: "Text to execute the regex on.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Index",
            description: "Index to get from the executed expression.",
            type: APIFunction_1.ParamType.Number,
            required: false,
            rest: false,
            defaultValue: "1"
        }];
    usage = "$execRegex[regex;flags?;text;index?]";
    returns = APIFunction_1.ParamType.String;
    aliases = [];
    compile = true;
    async run(d, [regex, flags = "g", text, index = "1"]) {
        if (!Util_1.Util.isNumber(index)) {
            throw new Error_1.EATS_Error(`Invalid number at: ${d.function.name}`);
        }
        if (regex.startsWith("/") && regex.endsWith("/"))
            regex = regex.slice(1, -1);
        const PATTERN = new RegExp(regex, flags);
        const RESULT = PATTERN.exec(text);
        return RESULT ? RESULT[Number(index) - 1] : "";
    }
}
exports.default = EncodeURI;
