"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
const Error_1 = require("../../structures/Error");
const Util_1 = require("../../classes/Util");
class StringAt extends APIFunction_1.APIFunction {
    name = "$stringAt";
    description = "Retrieves the character at the provided index.";
    parameters = [{
            name: "Text",
            description: "The text to work with.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Index",
            description: "Character index to get from the text.",
            type: APIFunction_1.ParamType.Number,
            required: true,
            rest: false,
            defaultValue: null
        }];
    usage = "$stringAt[text;index]";
    returns = APIFunction_1.ParamType.String;
    aliases = ["$charAt"];
    compile = true;
    async run(d, [text, index]) {
        if (!Util_1.Util.isNumber(index)) {
            throw new Error_1.EATS_Error(`Index must be a valid number at: ${d.function?.name}`);
        }
        else if (Util_1.Util.isNumber(index) && Number(index) < 1) {
            throw new Error_1.EATS_Error(`Index must be a valid number greater than 0 at: ${d.function?.name}`);
        }
        else if (Util_1.Util.isNumber(index) && Number(index) > text.length) {
            throw new Error_1.EATS_Error(`Index must be a valid number lower o equal than ${text.length} at: ${d.function?.name}`);
        }
        return text.charAt(Number(index) - 1);
    }
}
exports.default = StringAt;
