"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const APIFunction_1 = require("../../structures/APIFunction");
class StringReplaceRegex extends APIFunction_1.APIFunction {
    name = "$stringReplaceRegex";
    description = "Replace something in the provided text using regular expressions.";
    parameters = [{
            name: "Text",
            description: "The text to work with.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Regex",
            description: "The regular expression to be matched.",
            type: APIFunction_1.ParamType.String,
            required: true,
            rest: false,
            defaultValue: null
        }, {
            name: "Replacer",
            description: "The word to replace the match with.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: " "
        }, {
            name: "Flags",
            description: "The flags for the regular expression.",
            type: APIFunction_1.ParamType.String,
            required: false,
            rest: false,
            defaultValue: "g"
        }];
    usage = "$stringReplaceRegex[text;regex;replacer?;flags?]";
    returns = APIFunction_1.ParamType.String;
    aliases = ["$replaceWithRegex", "$replaceRegex", "$stringReplaceWithRegex"];
    compile = true;
    async run(d, [text, regex, replacer = "", flags = "g"]) {
        if (regex.startsWith("/") && regex.endsWith("/")) {
            regex = regex.slice(1, -1);
        }
        const CUSTOM_PATTERN = new RegExp(regex, flags);
        return text.replace(CUSTOM_PATTERN, replacer);
    }
}
exports.default = StringReplaceRegex;
