import { Database } from "midb";
interface AnyDatabase {
    get: (...args: any[]) => any;
    set: (...args: any[]) => any;
    delete: (...args: any[]) => any;
    has: (...args: any[]) => any;
}
export declare class DatabaseManager<T extends AnyDatabase = Database> {
    driver: T;
    constructor();
    /**
     * Set the database driver for this manager.
     * @param database - Database instance.
     * @returns {DatabaseManager}
     */
    setDatabase(database: T): this;
    /**
     * A value is deleted from the database.
     */
    deleteValue<V>(...args: V[]): Promise<string>;
    /**
     * Get a value from the database.
     */
    getValue<V>(...args: V[]): Promise<string>;
    /**
     * Check if the database has the given value.
     */
    hasValue<V>(...args: V[]): Promise<string>;
    /**
     * Set a value in the database.
     */
    setValue<V>(...args: V[]): Promise<string>;
    /**
     * Just a test method.
     */
    private test;
    /**
     * Starts the database driver.
     * @param callback - Callback to start the database driver with.
     */
    start<U extends () => any>(callback: U): void;
}
export {};
