"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatabaseManager = void 0;
const midb_1 = require("midb");
class DatabaseManager {
    driver = null;
    constructor() {
        this.driver = new midb_1.Database({
            path: './database',
            tables: ['main']
        });
    }
    /**
     * Set the database driver for this manager.
     * @param database - Database instance.
     * @returns {DatabaseManager}
     */
    setDatabase(database) {
        this.driver = database;
        return this;
    }
    /**
     * A value is deleted from the database.
     */
    async deleteValue(...args) {
        /*let callback = this.driver.delete.bind(this.driver)

        if (!isAsyncFunction(callback)) {
            callback = promisify(callback) as any
        }*/
        const result = await /*callback*/ this.driver.delete(...args);
        return typeof result === 'string' ? result
            : typeof result === 'number' ? result.toString()
                : typeof result === 'object' ? JSON.stringify(result, null, 2)
                    : String(result);
    }
    /**
     * Get a value from the database.
     */
    async getValue(...args) {
        /*let callback = this.driver.get.bind(this.driver)

        if (!isAsyncFunction(callback)) {
            callback = promisify(callback) as any
        }*/
        const result = await /*callback*/ this.driver.get(...args);
        return typeof result === 'string' ? result
            : typeof result === 'number' ? result.toString()
                : typeof result === 'object' ? JSON.stringify(result, null, 2)
                    : String(result);
    }
    /**
     * Check if the database has the given value.
     */
    async hasValue(...args) {
        /*let callback = this.driver.has.bind(this.driver)

        if (!isAsyncFunction(callback)) {
            callback = promisify(callback) as any
        }*/
        const result = await /*callback*/ this.driver.has(...args);
        return typeof result === 'string' ? result
            : typeof result === 'number' ? result.toString()
                : typeof result === 'object' ? JSON.stringify(result, null, 2)
                    : String(result);
    }
    /**
     * Set a value in the database.
     */
    async setValue(...args) {
        /*let callback = this.driver.set.bind(this.driver)

        if (!isAsyncFunction(callback)) {
            callback = promisify(callback) as any
        }*/
        const result = await /*callback*/ this.driver.set(...args);
        return typeof result === 'string' ? result
            : typeof result === 'number' ? result.toString()
                : typeof result === 'object' ? JSON.stringify(result, null, 2)
                    : String(result);
    }
    /**
     * Just a test method.
     */
    test(...args) {
        console.log(args);
        return args;
    }
    /**
     * Starts the database driver.
     * @param callback - Callback to start the database driver with.
     */
    start(callback) {
        if (callback)
            callback.call(this.driver);
    }
}
exports.DatabaseManager = DatabaseManager;
