"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.APIFunction = exports.FunctionReturn = exports.ParamType = void 0;
/**
 * Represents a function parameter type.
 */
var ParamType;
(function (ParamType) {
    /**
     * A data type that can represent whole numbers larger than those representable by the Number type.
     */
    ParamType[ParamType["BigInt"] = 0] = "BigInt";
    /**
     * A data type that can be either true or false.
     */
    ParamType[ParamType["Boolean"] = 1] = "Boolean";
    /**
     * A data type that represents color values. This can be in formats like hex, RGB, HSL, etc.
     */
    ParamType[ParamType["Color"] = 2] = "Color";
    /**
     * A data type that represents a date and time.
     * Any value that can be passed to JavaScript's `new Date()` is accepted.
     */
    ParamType[ParamType["Date"] = 3] = "Date";
    /**
     * A data type that represents data in JavaScript Object Notation (JSON) format.
     */
    ParamType[ParamType["JSON"] = 4] = "JSON";
    /**
     * An object that is similar to an array. Any object with indexed properties.
     */
    ParamType[ParamType["List"] = 5] = "List";
    /**
     * A valid numeric expression.
     */
    ParamType[ParamType["Number"] = 6] = "Number";
    /**
     * A data type that represents a sequence of characters.
     */
    ParamType[ParamType["String"] = 7] = "String";
    /**
     * A data type that represents a time of day or a duration.
     * Should be a valid millisecond number or valid string parseable to time.
     */
    ParamType[ParamType["Time"] = 8] = "Time";
    /**
     * A data type that can be any.
     */
    ParamType[ParamType["Unknown"] = 9] = "Unknown";
})(ParamType || (exports.ParamType = ParamType = {}));
;
/**
 * Represents a function return type.
 * @deprecated Use ParamType enumerator instead.
 */
var FunctionReturn;
(function (FunctionReturn) {
    FunctionReturn[FunctionReturn["Array"] = 0] = "Array";
    FunctionReturn[FunctionReturn["Boolean"] = 1] = "Boolean";
    FunctionReturn[FunctionReturn["Number"] = 2] = "Number";
    FunctionReturn[FunctionReturn["JSON"] = 3] = "JSON";
    FunctionReturn[FunctionReturn["String"] = 4] = "String";
    FunctionReturn[FunctionReturn["Unknown"] = 5] = "Unknown";
})(FunctionReturn || (exports.FunctionReturn = FunctionReturn = {}));
/**
 * Represents an easy-api.ts native function.
 */
class APIFunction {
    name;
    description;
    usage;
    parameters;
    returns;
    compile;
    aliases;
    async run(d, args) {
        return;
    }
    ;
    parent;
    example;
    init() {
        if (!Array.isArray(this.aliases))
            this.aliases = [];
        if (typeof (this.compile) !== "boolean")
            this.compile = true;
        if (!Array.isArray(this.parameters))
            this.parameters = [];
        if (!this.usage)
            this.usage = `${this.name}${this.parameters.length > 0 ? ("[" + this.parameters.map(arg => arg.required ? arg.name.toLowerCase() : `${arg.name.toLowerCase()}?`).join(";") + "]") : ""}`;
        if (!this.returns)
            this.returns = ParamType.Unknown;
    }
}
exports.APIFunction = APIFunction;
;
